---
title: 0.4
---
The 0.4 version comes with an auto-reloading web-server, enabling you to prototype your site faster.

It also support adding files in the top level directory, like favicon.ico and CNAME.
